texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: LaTeX.pm: do not output quotes for empty @*table


From: Patrice Dumas
Subject: branch master updated: LaTeX.pm: do not output quotes for empty @*table @item. Add an empty item for text before item in @*table
Date: Sun, 22 Aug 2021 15:42:26 -0400

This is an automated email from the git hooks/post-receive script.

pertusus pushed a commit to branch master
in repository texinfo.

The following commit(s) were added to refs/heads/master by this push:
     new 478f498  LaTeX.pm: do not output quotes for empty @*table @item. Add 
an empty item for text before item in @*table
478f498 is described below

commit 478f498c79a7609fae20f9a0d922e303fb504117
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Sun Aug 22 21:40:57 2021 +0200

    LaTeX.pm: do not output quotes for empty @*table @item.
    Add an empty item for text before item in @*table
---
 tp/Texinfo/Convert/LaTeX.pm                        | 22 ++++++++++++++++----
 .../res_latex/inter_item_commands_in_enumerate.tex |  4 ++--
 .../res_latex/inter_item_commands_in_itemize.tex   |  4 ++--
 ...anchor_links_xref_xrefautomaticsectiontitle.tex |  4 ++--
 .../res_latex/enumerate_arguments.tex              |  4 ++--
 .../res_latex/example_in_cartouche.tex             |  4 ++--
 .../float_and_refs/res_latex/float_and_refs.tex    |  4 ++--
 .../fonttextsize/res_latex/fonttextsize.tex        |  4 ++--
 .../res_latex/nested_enumerate.tex                 |  4 ++--
 .../nested_itemize/res_latex/nested_itemize.tex    |  4 ++--
 .../no_titlepage_and_setchapternewpage_odd.tex     |  4 ++--
 .../no_titlepage_and_setchapternewpage_on.tex      |  4 ++--
 .../latex_tests/pagesizes/res_latex/pagesizes.tex  |  4 ++--
 .../latex_tests/pagetype/res_latex/pagetype.tex    |  4 ++--
 .../setchapternewpage_on_odd_titlepage.tex         |  4 ++--
 .../res_latex/settitle_and_headings.tex            |  4 ++--
 .../shorttitlepage/res_latex/shorttitlepage.tex    |  4 ++--
 .../three_setchapternewpage_on_odd_off.tex         |  4 ++--
 .../res_latex/titlepage_and_headings.tex           |  4 ++--
 .../titlepage_and_setchapternewpage_odd.tex        |  4 ++--
 .../titlepage_and_setchapternewpage_on.tex         |  4 ++--
 .../res_latex/titlepage_classical.tex              |  4 ++--
 .../res_latex/titlepage_in_top_node.tex            |  4 ++--
 .../res_latex/titlepage_long_title.tex             |  4 ++--
 .../res_latex/titlepage_no_author.tex              |  4 ++--
 .../res_latex/titlepage_no_title.tex               |  4 ++--
 .../titlepage_with_commands_classical.tex          |  4 ++--
 .../res_latex/two_setchapternewpage_odd_on.tex     |  4 ++--
 .../res_latex/two_setchapternewpage_on_odd.tex     |  4 ++--
 .../res_latex/verbatim_in_smallformat.tex          |  4 ++--
 .../empty_quotation/res_latex/empty_quotation.tex  |  4 ++--
 .../res_latex/quotation_and_author.tex             |  4 ++--
 .../res_latex/quotation_author_in_example.tex      |  4 ++--
 .../space_at_commands_end_quotation_line.tex       |  4 ++--
 .../res_latex/chapter_between_nodes.tex            |  4 ++--
 .../lone_Top_node/res_latex/lone_Top_node.tex      |  4 ++--
 .../sectioning/loop_nodes/res_latex/loop_nodes.tex |  4 ++--
 .../node_sectop_before_chapter_no_node.tex         |  4 ++--
 .../res_latex/node_sectop_before_lone_node_Top.tex |  4 ++--
 .../res_latex/nodes_before_after_top.tex           |  4 ++--
 .../res_latex/nodes_before_after_top_xref.tex      |  4 ++--
 .../res_latex/nodes_before_top.tex                 |  4 ++--
 .../res_latex/section_before_after_top_node.tex    |  4 ++--
 .../section_before_after_top_node_last_node.tex    |  4 ++--
 .../res_latex/section_chapter_before_top_nodes.tex |  4 ++--
 .../res_latex/inter_item_commands_in_table.tex     |  8 ++++----
 .../inter_item_commands_in_table_in_example.tex    |  4 ++--
 .../res_parser/formatting_latex/formatting.tex     | 24 +++++++++++-----------
 48 files changed, 124 insertions(+), 110 deletions(-)

diff --git 
a/tp/t/results/itemize/inter_item_commands_in_enumerate/res_latex/inter_item_commands_in_enumerate.tex
 
b/tp/t/results/itemize/inter_item_commands_in_enumerate/res_latex/inter_item_commands_in_enumerate.tex
index c4e9c8b..32f7ac0 100644
--- 
a/tp/t/results/itemize/inter_item_commands_in_enumerate/res_latex/inter_item_commands_in_enumerate.tex
+++ 
b/tp/t/results/itemize/inter_item_commands_in_enumerate/res_latex/inter_item_commands_in_enumerate.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/itemize/inter_item_commands_in_itemize/res_latex/inter_item_commands_in_itemize.tex
 
b/tp/t/results/itemize/inter_item_commands_in_itemize/res_latex/inter_item_commands_in_itemize.tex
index d630653..39b686e 100644
--- 
a/tp/t/results/itemize/inter_item_commands_in_itemize/res_latex/inter_item_commands_in_itemize.tex
+++ 
b/tp/t/results/itemize/inter_item_commands_in_itemize/res_latex/inter_item_commands_in_itemize.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/anchor_links_xref_xrefautomaticsectiontitle/res_latex/anchor_links_xref_xrefautomaticsectiontitle.tex
 
b/tp/t/results/latex_tests/anchor_links_xref_xrefautomaticsectiontitle/res_latex/anchor_links_xref_xrefautomaticsectiontitle.tex
index c62640b..26dc9f2 100644
--- 
a/tp/t/results/latex_tests/anchor_links_xref_xrefautomaticsectiontitle/res_latex/anchor_links_xref_xrefautomaticsectiontitle.tex
+++ 
b/tp/t/results/latex_tests/anchor_links_xref_xrefautomaticsectiontitle/res_latex/anchor_links_xref_xrefautomaticsectiontitle.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/enumerate_arguments/res_latex/enumerate_arguments.tex
 
b/tp/t/results/latex_tests/enumerate_arguments/res_latex/enumerate_arguments.tex
index 8721fd3..321faab 100644
--- 
a/tp/t/results/latex_tests/enumerate_arguments/res_latex/enumerate_arguments.tex
+++ 
b/tp/t/results/latex_tests/enumerate_arguments/res_latex/enumerate_arguments.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/example_in_cartouche/res_latex/example_in_cartouche.tex
 
b/tp/t/results/latex_tests/example_in_cartouche/res_latex/example_in_cartouche.tex
index 4ea4b8c..4029e0d 100644
--- 
a/tp/t/results/latex_tests/example_in_cartouche/res_latex/example_in_cartouche.tex
+++ 
b/tp/t/results/latex_tests/example_in_cartouche/res_latex/example_in_cartouche.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/float_and_refs/res_latex/float_and_refs.tex 
b/tp/t/results/latex_tests/float_and_refs/res_latex/float_and_refs.tex
index 3225a60..ffcf359 100644
--- a/tp/t/results/latex_tests/float_and_refs/res_latex/float_and_refs.tex
+++ b/tp/t/results/latex_tests/float_and_refs/res_latex/float_and_refs.tex
@@ -25,10 +25,10 @@
 \newfloat{TexinfoFloatThing}{htb}{tfl}[chapter]
 \floatname{TexinfoFloatThing}{}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/t/results/latex_tests/fonttextsize/res_latex/fonttextsize.tex 
b/tp/t/results/latex_tests/fonttextsize/res_latex/fonttextsize.tex
index ace34b6..8700459 100644
--- a/tp/t/results/latex_tests/fonttextsize/res_latex/fonttextsize.tex
+++ b/tp/t/results/latex_tests/fonttextsize/res_latex/fonttextsize.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/nested_enumerate/res_latex/nested_enumerate.tex 
b/tp/t/results/latex_tests/nested_enumerate/res_latex/nested_enumerate.tex
index a154e82..2e19981 100644
--- a/tp/t/results/latex_tests/nested_enumerate/res_latex/nested_enumerate.tex
+++ b/tp/t/results/latex_tests/nested_enumerate/res_latex/nested_enumerate.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/nested_itemize/res_latex/nested_itemize.tex 
b/tp/t/results/latex_tests/nested_itemize/res_latex/nested_itemize.tex
index cb7f572..6a74fe4 100644
--- a/tp/t/results/latex_tests/nested_itemize/res_latex/nested_itemize.tex
+++ b/tp/t/results/latex_tests/nested_itemize/res_latex/nested_itemize.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_odd/res_latex/no_titlepage_and_setchapternewpage_odd.tex
 
b/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_odd/res_latex/no_titlepage_and_setchapternewpage_odd.tex
index 845394b..4dd18f4 100644
--- 
a/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_odd/res_latex/no_titlepage_and_setchapternewpage_odd.tex
+++ 
b/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_odd/res_latex/no_titlepage_and_setchapternewpage_odd.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_on/res_latex/no_titlepage_and_setchapternewpage_on.tex
 
b/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_on/res_latex/no_titlepage_and_setchapternewpage_on.tex
index 1f20271..a6290cf 100644
--- 
a/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_on/res_latex/no_titlepage_and_setchapternewpage_on.tex
+++ 
b/tp/t/results/latex_tests/no_titlepage_and_setchapternewpage_on/res_latex/no_titlepage_and_setchapternewpage_on.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/t/results/latex_tests/pagesizes/res_latex/pagesizes.tex 
b/tp/t/results/latex_tests/pagesizes/res_latex/pagesizes.tex
index e8760ce..8cb82a9 100644
--- a/tp/t/results/latex_tests/pagesizes/res_latex/pagesizes.tex
+++ b/tp/t/results/latex_tests/pagesizes/res_latex/pagesizes.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/t/results/latex_tests/pagetype/res_latex/pagetype.tex 
b/tp/t/results/latex_tests/pagetype/res_latex/pagetype.tex
index 39df4cf..a138314 100644
--- a/tp/t/results/latex_tests/pagetype/res_latex/pagetype.tex
+++ b/tp/t/results/latex_tests/pagetype/res_latex/pagetype.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/setchapternewpage_on_odd_titlepage/res_latex/setchapternewpage_on_odd_titlepage.tex
 
b/tp/t/results/latex_tests/setchapternewpage_on_odd_titlepage/res_latex/setchapternewpage_on_odd_titlepage.tex
index d5d0948..0a7b899 100644
--- 
a/tp/t/results/latex_tests/setchapternewpage_on_odd_titlepage/res_latex/setchapternewpage_on_odd_titlepage.tex
+++ 
b/tp/t/results/latex_tests/setchapternewpage_on_odd_titlepage/res_latex/setchapternewpage_on_odd_titlepage.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/settitle_and_headings/res_latex/settitle_and_headings.tex
 
b/tp/t/results/latex_tests/settitle_and_headings/res_latex/settitle_and_headings.tex
index 377d616..291eddb 100644
--- 
a/tp/t/results/latex_tests/settitle_and_headings/res_latex/settitle_and_headings.tex
+++ 
b/tp/t/results/latex_tests/settitle_and_headings/res_latex/settitle_and_headings.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/shorttitlepage/res_latex/shorttitlepage.tex 
b/tp/t/results/latex_tests/shorttitlepage/res_latex/shorttitlepage.tex
index e033b90..a69e038 100644
--- a/tp/t/results/latex_tests/shorttitlepage/res_latex/shorttitlepage.tex
+++ b/tp/t/results/latex_tests/shorttitlepage/res_latex/shorttitlepage.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/three_setchapternewpage_on_odd_off/res_latex/three_setchapternewpage_on_odd_off.tex
 
b/tp/t/results/latex_tests/three_setchapternewpage_on_odd_off/res_latex/three_setchapternewpage_on_odd_off.tex
index 62f17aa..007a94a 100644
--- 
a/tp/t/results/latex_tests/three_setchapternewpage_on_odd_off/res_latex/three_setchapternewpage_on_odd_off.tex
+++ 
b/tp/t/results/latex_tests/three_setchapternewpage_on_odd_off/res_latex/three_setchapternewpage_on_odd_off.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_and_headings/res_latex/titlepage_and_headings.tex
 
b/tp/t/results/latex_tests/titlepage_and_headings/res_latex/titlepage_and_headings.tex
index c44a4dc..7ad0c94 100644
--- 
a/tp/t/results/latex_tests/titlepage_and_headings/res_latex/titlepage_and_headings.tex
+++ 
b/tp/t/results/latex_tests/titlepage_and_headings/res_latex/titlepage_and_headings.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_and_setchapternewpage_odd/res_latex/titlepage_and_setchapternewpage_odd.tex
 
b/tp/t/results/latex_tests/titlepage_and_setchapternewpage_odd/res_latex/titlepage_and_setchapternewpage_odd.tex
index 85f2491..7e1e2f3 100644
--- 
a/tp/t/results/latex_tests/titlepage_and_setchapternewpage_odd/res_latex/titlepage_and_setchapternewpage_odd.tex
+++ 
b/tp/t/results/latex_tests/titlepage_and_setchapternewpage_odd/res_latex/titlepage_and_setchapternewpage_odd.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_and_setchapternewpage_on/res_latex/titlepage_and_setchapternewpage_on.tex
 
b/tp/t/results/latex_tests/titlepage_and_setchapternewpage_on/res_latex/titlepage_and_setchapternewpage_on.tex
index c44a4dc..7ad0c94 100644
--- 
a/tp/t/results/latex_tests/titlepage_and_setchapternewpage_on/res_latex/titlepage_and_setchapternewpage_on.tex
+++ 
b/tp/t/results/latex_tests/titlepage_and_setchapternewpage_on/res_latex/titlepage_and_setchapternewpage_on.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_classical/res_latex/titlepage_classical.tex
 
b/tp/t/results/latex_tests/titlepage_classical/res_latex/titlepage_classical.tex
index 4c307bd..9c685c6 100644
--- 
a/tp/t/results/latex_tests/titlepage_classical/res_latex/titlepage_classical.tex
+++ 
b/tp/t/results/latex_tests/titlepage_classical/res_latex/titlepage_classical.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_in_top_node/res_latex/titlepage_in_top_node.tex
 
b/tp/t/results/latex_tests/titlepage_in_top_node/res_latex/titlepage_in_top_node.tex
index 8908989..3d8577e 100644
--- 
a/tp/t/results/latex_tests/titlepage_in_top_node/res_latex/titlepage_in_top_node.tex
+++ 
b/tp/t/results/latex_tests/titlepage_in_top_node/res_latex/titlepage_in_top_node.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_long_title/res_latex/titlepage_long_title.tex
 
b/tp/t/results/latex_tests/titlepage_long_title/res_latex/titlepage_long_title.tex
index c5b3379..3fbdf69 100644
--- 
a/tp/t/results/latex_tests/titlepage_long_title/res_latex/titlepage_long_title.tex
+++ 
b/tp/t/results/latex_tests/titlepage_long_title/res_latex/titlepage_long_title.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_no_author/res_latex/titlepage_no_author.tex
 
b/tp/t/results/latex_tests/titlepage_no_author/res_latex/titlepage_no_author.tex
index 87c95ce..c875d8a 100644
--- 
a/tp/t/results/latex_tests/titlepage_no_author/res_latex/titlepage_no_author.tex
+++ 
b/tp/t/results/latex_tests/titlepage_no_author/res_latex/titlepage_no_author.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_no_title/res_latex/titlepage_no_title.tex 
b/tp/t/results/latex_tests/titlepage_no_title/res_latex/titlepage_no_title.tex
index 73d99b7..4cf73ad 100644
--- 
a/tp/t/results/latex_tests/titlepage_no_title/res_latex/titlepage_no_title.tex
+++ 
b/tp/t/results/latex_tests/titlepage_no_title/res_latex/titlepage_no_title.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/titlepage_with_commands_classical/res_latex/titlepage_with_commands_classical.tex
 
b/tp/t/results/latex_tests/titlepage_with_commands_classical/res_latex/titlepage_with_commands_classical.tex
index a529c62..ea6214e 100644
--- 
a/tp/t/results/latex_tests/titlepage_with_commands_classical/res_latex/titlepage_with_commands_classical.tex
+++ 
b/tp/t/results/latex_tests/titlepage_with_commands_classical/res_latex/titlepage_with_commands_classical.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/two_setchapternewpage_odd_on/res_latex/two_setchapternewpage_odd_on.tex
 
b/tp/t/results/latex_tests/two_setchapternewpage_odd_on/res_latex/two_setchapternewpage_odd_on.tex
index 09a404c..29e7468 100644
--- 
a/tp/t/results/latex_tests/two_setchapternewpage_odd_on/res_latex/two_setchapternewpage_odd_on.tex
+++ 
b/tp/t/results/latex_tests/two_setchapternewpage_odd_on/res_latex/two_setchapternewpage_odd_on.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/two_setchapternewpage_on_odd/res_latex/two_setchapternewpage_on_odd.tex
 
b/tp/t/results/latex_tests/two_setchapternewpage_on_odd/res_latex/two_setchapternewpage_on_odd.tex
index b79d99f..4408971 100644
--- 
a/tp/t/results/latex_tests/two_setchapternewpage_on_odd/res_latex/two_setchapternewpage_on_odd.tex
+++ 
b/tp/t/results/latex_tests/two_setchapternewpage_on_odd/res_latex/two_setchapternewpage_on_odd.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/latex_tests/verbatim_in_smallformat/res_latex/verbatim_in_smallformat.tex
 
b/tp/t/results/latex_tests/verbatim_in_smallformat/res_latex/verbatim_in_smallformat.tex
index 6bd21a1..ec2ca51 100644
--- 
a/tp/t/results/latex_tests/verbatim_in_smallformat/res_latex/verbatim_in_smallformat.tex
+++ 
b/tp/t/results/latex_tests/verbatim_in_smallformat/res_latex/verbatim_in_smallformat.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/quotation/empty_quotation/res_latex/empty_quotation.tex 
b/tp/t/results/quotation/empty_quotation/res_latex/empty_quotation.tex
index 2850a6d..fa316a4 100644
--- a/tp/t/results/quotation/empty_quotation/res_latex/empty_quotation.tex
+++ b/tp/t/results/quotation/empty_quotation/res_latex/empty_quotation.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/quotation/quotation_and_author/res_latex/quotation_and_author.tex
 
b/tp/t/results/quotation/quotation_and_author/res_latex/quotation_and_author.tex
index fe48a73..4da0be9 100644
--- 
a/tp/t/results/quotation/quotation_and_author/res_latex/quotation_and_author.tex
+++ 
b/tp/t/results/quotation/quotation_and_author/res_latex/quotation_and_author.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/quotation/quotation_author_in_example/res_latex/quotation_author_in_example.tex
 
b/tp/t/results/quotation/quotation_author_in_example/res_latex/quotation_author_in_example.tex
index d69bb3a..6a09793 100644
--- 
a/tp/t/results/quotation/quotation_author_in_example/res_latex/quotation_author_in_example.tex
+++ 
b/tp/t/results/quotation/quotation_author_in_example/res_latex/quotation_author_in_example.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/quotation/space_at_commands_end_quotation_line/res_latex/space_at_commands_end_quotation_line.tex
 
b/tp/t/results/quotation/space_at_commands_end_quotation_line/res_latex/space_at_commands_end_quotation_line.tex
index 71a1de9..3bc8f83 100644
--- 
a/tp/t/results/quotation/space_at_commands_end_quotation_line/res_latex/space_at_commands_end_quotation_line.tex
+++ 
b/tp/t/results/quotation/space_at_commands_end_quotation_line/res_latex/space_at_commands_end_quotation_line.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/chapter_between_nodes/res_latex/chapter_between_nodes.tex
 
b/tp/t/results/sectioning/chapter_between_nodes/res_latex/chapter_between_nodes.tex
index 802d526..bd1b03e 100644
--- 
a/tp/t/results/sectioning/chapter_between_nodes/res_latex/chapter_between_nodes.tex
+++ 
b/tp/t/results/sectioning/chapter_between_nodes/res_latex/chapter_between_nodes.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/t/results/sectioning/lone_Top_node/res_latex/lone_Top_node.tex 
b/tp/t/results/sectioning/lone_Top_node/res_latex/lone_Top_node.tex
index c1b296a..36cd0a1 100644
--- a/tp/t/results/sectioning/lone_Top_node/res_latex/lone_Top_node.tex
+++ b/tp/t/results/sectioning/lone_Top_node/res_latex/lone_Top_node.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/t/results/sectioning/loop_nodes/res_latex/loop_nodes.tex 
b/tp/t/results/sectioning/loop_nodes/res_latex/loop_nodes.tex
index a39ac99..1daef56 100644
--- a/tp/t/results/sectioning/loop_nodes/res_latex/loop_nodes.tex
+++ b/tp/t/results/sectioning/loop_nodes/res_latex/loop_nodes.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/node_sectop_before_chapter_no_node/res_latex/node_sectop_before_chapter_no_node.tex
 
b/tp/t/results/sectioning/node_sectop_before_chapter_no_node/res_latex/node_sectop_before_chapter_no_node.tex
index 2eaf0ac..65cc96c 100644
--- 
a/tp/t/results/sectioning/node_sectop_before_chapter_no_node/res_latex/node_sectop_before_chapter_no_node.tex
+++ 
b/tp/t/results/sectioning/node_sectop_before_chapter_no_node/res_latex/node_sectop_before_chapter_no_node.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/node_sectop_before_lone_node_Top/res_latex/node_sectop_before_lone_node_Top.tex
 
b/tp/t/results/sectioning/node_sectop_before_lone_node_Top/res_latex/node_sectop_before_lone_node_Top.tex
index 8cff54c..f367296 100644
--- 
a/tp/t/results/sectioning/node_sectop_before_lone_node_Top/res_latex/node_sectop_before_lone_node_Top.tex
+++ 
b/tp/t/results/sectioning/node_sectop_before_lone_node_Top/res_latex/node_sectop_before_lone_node_Top.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/nodes_before_after_top/res_latex/nodes_before_after_top.tex
 
b/tp/t/results/sectioning/nodes_before_after_top/res_latex/nodes_before_after_top.tex
index 303ec87..5a20a8b 100644
--- 
a/tp/t/results/sectioning/nodes_before_after_top/res_latex/nodes_before_after_top.tex
+++ 
b/tp/t/results/sectioning/nodes_before_after_top/res_latex/nodes_before_after_top.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/nodes_before_after_top_xref/res_latex/nodes_before_after_top_xref.tex
 
b/tp/t/results/sectioning/nodes_before_after_top_xref/res_latex/nodes_before_after_top_xref.tex
index 6508742..181e023 100644
--- 
a/tp/t/results/sectioning/nodes_before_after_top_xref/res_latex/nodes_before_after_top_xref.tex
+++ 
b/tp/t/results/sectioning/nodes_before_after_top_xref/res_latex/nodes_before_after_top_xref.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/nodes_before_top/res_latex/nodes_before_top.tex 
b/tp/t/results/sectioning/nodes_before_top/res_latex/nodes_before_top.tex
index 5bca8b4..9908bde 100644
--- a/tp/t/results/sectioning/nodes_before_top/res_latex/nodes_before_top.tex
+++ b/tp/t/results/sectioning/nodes_before_top/res_latex/nodes_before_top.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/section_before_after_top_node/res_latex/section_before_after_top_node.tex
 
b/tp/t/results/sectioning/section_before_after_top_node/res_latex/section_before_after_top_node.tex
index 20cb711..f713fa8 100644
--- 
a/tp/t/results/sectioning/section_before_after_top_node/res_latex/section_before_after_top_node.tex
+++ 
b/tp/t/results/sectioning/section_before_after_top_node/res_latex/section_before_after_top_node.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/section_before_after_top_node_last_node/res_latex/section_before_after_top_node_last_node.tex
 
b/tp/t/results/sectioning/section_before_after_top_node_last_node/res_latex/section_before_after_top_node_last_node.tex
index 275c7fb..896314b 100644
--- 
a/tp/t/results/sectioning/section_before_after_top_node_last_node/res_latex/section_before_after_top_node_last_node.tex
+++ 
b/tp/t/results/sectioning/section_before_after_top_node_last_node/res_latex/section_before_after_top_node_last_node.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/sectioning/section_chapter_before_top_nodes/res_latex/section_chapter_before_top_nodes.tex
 
b/tp/t/results/sectioning/section_chapter_before_top_nodes/res_latex/section_chapter_before_top_nodes.tex
index 33a81a6..1d9811c 100644
--- 
a/tp/t/results/sectioning/section_chapter_before_top_nodes/res_latex/section_chapter_before_top_nodes.tex
+++ 
b/tp/t/results/sectioning/section_chapter_before_top_nodes/res_latex/section_chapter_before_top_nodes.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git 
a/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
 
b/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
index 1514744..bf24afd 100644
--- 
a/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
+++ 
b/tp/t/results/xtable/inter_item_commands_in_table/res_latex/inter_item_commands_in_table.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
@@ -114,7 +114,7 @@ l--ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Texte before first item.
+\item[] Texte before first item.
 \item[abb]
 \end{description}
 
@@ -124,7 +124,7 @@ l--ine samp
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Texte before first item samp.
+\item[] Texte before first item samp.
 \item[asamp{-}{-}bb]
 \end{description}
 \end{document}
diff --git 
a/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
 
b/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
index 27b0cbc..5c771e6 100644
--- 
a/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
+++ 
b/tp/t/results/xtable/inter_item_commands_in_table_in_example/res_latex/inter_item_commands_in_table_in_example.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
diff --git a/tp/tests/layout/res_parser/formatting_latex/formatting.tex 
b/tp/tests/layout/res_parser/formatting_latex/formatting.tex
index 136d78d..3995b9f 100644
--- a/tp/tests/layout/res_parser/formatting_latex/formatting.tex
+++ b/tp/tests/layout/res_parser/formatting_latex/formatting.tex
@@ -19,10 +19,10 @@
 \usepackage[hidelinks]{hyperref}
 \usepackage[utf8]{inputenc}
 % command used in \description format for indicateurl
-\newcommand\GNUTexinfotablestyleindicateurl[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestyleindicateurl[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 % command used in \description format for samp
-\newcommand\GNUTexinfotablestylesamp[1]{`\texttt{#1}'}%
+\newcommand\GNUTexinfotablestylesamp[1]{\ifstrempty{#1}{}{`\texttt{#1}'}}%
 
 
 % redefine the \mainmatter command such that it does not clear page
@@ -852,13 +852,13 @@ l--ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Title
+\item[] Title
 \item[a{-}{-}code]
 Value--table code
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Title
+\item[] Title
 \item[a{-}{-}samp]
 \item[a2{-}{-}samp]
 Value--table samp
@@ -1797,13 +1797,13 @@ l--ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Title
+\item[] Title
 \item[a{-}{-}code]
 Value--table code
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Title
+\item[] Title
 \item[a{-}{-}samp]
 \item[a2{-}{-}samp]
 Value--table samp
@@ -2757,13 +2757,13 @@ l--ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Title
+\item[] Title
 \item[a{-}{-}code]
 Value--table code
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Title
+\item[] Title
 \item[a{-}{-}samp]
 \item[a2{-}{-}samp]
 Value--table samp
@@ -3700,13 +3700,13 @@ l--ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Title
+\item[] Title
 \item[a{-}{-}code]
 Value--table code
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Title
+\item[] Title
 \item[a{-}{-}samp]
 \item[a2{-}{-}samp]
 Value--table samp
@@ -4656,13 +4656,13 @@ l{-}{-}ine
 \end{description}
 
 \begin{description}[format=\texttt]
-\item Title
+\item[] Title
 \item[a{-}{-}code]
 Value{-}{-}table code
 \end{description}
 
 \begin{description}[format=\GNUTexinfotablestylesamp]
-\item Title
+\item[] Title
 \item[a{-}{-}samp]
 \item[a2{-}{-}samp]
 Value{-}{-}table samp



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/tp/Texinfo/Convert/LaTeX.pm b/tp/Texinfo/Convert/LaTeX.pm
index 02b0e3b..a62d175 100644
--- a/tp/Texinfo/Convert/LaTeX.pm
+++ b/tp/Texinfo/Convert/LaTeX.pm
@@ -631,15 +631,22 @@ foreach my $quoted_command (@quoted_commands) {
   # does not happen currently
   if ($description_format eq '') {
     $description_command_new_commands{$quoted_command} =
-            "$specific_format_command\[1]{`#1'}";
+            "$specific_format_command\[1]{\\ifstrempty{#1}{}{`#1'}}";
   } else {
     my $prepended_normalfont = '';
     if ($description_format !~ /\\text[a-z]{2}$/) {
       # use \normalfont to avoid default bold
       $prepended_normalfont = '\normalfont{}';
     }
+    # We use \ifstrempty to avoid outputting an empty
+    # quotation if there is no item.  Note that it does
+    # not work as intended if there is no optional parameter
+    # for item, like
+    #   \item some text
+    # but works for
+    #   \item[] some text
     $description_command_new_commands{$quoted_command} =
-            
"$specific_format_command\[1]{$prepended_normalfont`$description_format\{#1}'}";
+            
"$specific_format_command\[1]{\\ifstrempty{#1}{}{$prepended_normalfont`$description_format\{#1}'}}";
   }
   $description_command_format{$quoted_command} = $specific_format_command;
 }
@@ -1007,7 +1014,7 @@ sub _latex_header {
   # textcomp for \textdegree in older LaTeX
   # graphicx for \includegraphics
   # needspace for \needspace. In texlive-latex-extra in debian
   # etoolbox for \patchcmd. In texlive-latex-recommended in debian
debian
   # fontsize for \changefontsize. In texlive-latex-extra in debian
   # mdframed for the formatting of @cartouche
   # \usepackage[linkbordercolor={0 0 0}]{hyperref}
@@ -2840,7 +2847,14 @@ sub _convert($$)
     } elsif ($root->{'type'} eq 'before_item') {
       # LaTeX environments do not accept text before the first item, add an 
item
       if ($result =~ /\S/) {
-        $result = '\item '.$result;
+        if ($item_line_commands{$root->{'parent'}->{'cmdname'}}) {
+          # it is important to have an empty optional argument otherwise
+          # a quoted command will output the quotes, even with a detection
+          # of empty argument (tested with diverse possibilities)
+          $result = '\item[] '.$result;
+        } else {
+          $result = '\item '.$result;
+        }
       }
     } elsif ($root->{'type'} eq 'row') {
       # ...
@@ -1007,7 +1014,7 @@ sub _latex_header {
   # graphicx for \includegraphics
   # needspace for \needspace. In texlive-latex-extra in debian
-  # etoolbox for \patchcmd. In texlive-latex-recommended in debian
+  # etoolbox for \patchcmd and \ifstrempty. In texlive-latex-recommended in 
debian
   # fontsize for \changefontsize. In texlive-latex-extra in debian